@@ -66,7 +66,7 @@ class GSPeerConnectionWatcher:
             async def on_track(track):
                 if track.kind == "video":
                     if self.ontrack is not None:
-                        await self.ontrack(self.gsdbs, track)
+                        await self.ontrack(self.gsdbs, track,target)
 
                 @track.on("ended")
                 async def on_ended():
